@@ -8,8 +8,10 @@ class ProblemConstantSet:
                  yes_str: str = None,
                  no_str: str = None,
                  judge_method: Judge = None,
+                 timeout: float = None
                  ):
         self.mod = mod
         self.yes_str = yes_str
         self.no_str = no_str
         self.judge_method = judge_method
+        self.timeout = timeout
